package apitests

import (
	"net/http"
	"os"
	"testing"
	"time"

	"github.com/kyma-project/kyma/tests/integration/event-service/test/testkit"
	"github.com/sirupsen/logrus"
)

const (
	istioSidecarStartWaitTime      = 60 * time.Second
	istioSidecarStartCheckInterval = 2 * time.Second
)

var (
	config testkit.TestConfig
)

func TestMain(m *testing.M) {
	var err error

	config, err = testkit.ReadConfig()
	if err != nil {
		logrus.Errorf("Failed to read configuration: %s", err.Error())
		os.Exit(1)
	}

	err = waitForIstioSidecar()
	if err != nil {
		logrus.Error("Error waiting for Istio sidecar to start: %s", err.Error())
		os.Exit(1)
	}

	code := m.Run()
	os.Exit(code)
}

func waitForIstioSidecar() error {
	return testkit.WaitForFunction(istioSidecarStartCheckInterval, istioSidecarStartWaitTime, func() bool {
		url := config.EventServiceUrl + "/v1/health"

		response, err := http.Get(url)
		if err != nil {
			logrus.Warn("Failed to access health endpoint while waiting for sidecar to start. Retrying in %s: %s",
				istioSidecarStartCheckInterval.String(), err.Error())
			return false
		}
		defer func() {
			err := response.Body.Close()
			if err != nil {
				logrus.Warn("Failed to close response body: %s", err.Error())
			}
		}()

		if response.StatusCode != http.StatusOK {
			logrus.Warn("Received invalid response while waiting for sidecar to start. Retrying in %s: Status %s",
				istioSidecarStartCheckInterval.String(), response.Status)
			return false
		}

		logrus.Info("Successfully accessed health endpoint")
		return true
	})

}
